==> lfortran-0.1.15.tar.gz: lfortran-0.1.15/lfortran/ast/tests/controlflow_results.py <==
results = [
    ('WhileLoop', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'x'), ('Eq',), ('Name', (1, 1), 'y')), [('Assignment', (1, 1), ('Name', (1, 1), 'i'), ('BinOp', (1, 1), ('Name', (1, 1), 'i'), ('Add',), ('Num', (1, 1), '1'))), ('Cycle', (1, 1)), ('Exit', (1, 1))]),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('If', (1, 1), ('Name', (1, 1), 'b'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [])])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('If', (1, 1), ('Name', (1, 1), 'b'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [('If', (1, 1), ('Name', (1, 1), 'c'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [])])])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1')), ('Assignment', (1, 1), ('Name', (1, 1), 'y'), ('Num', (1, 1), '2'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), None, [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), ('do_loop_head', 'i', ('Num', (1, 1), '1'), ('Num', (1, 1), '5'), None), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('BinOp', (1, 1), ('Name', (1, 1), 'x'), ('Add',), ('Name', (1, 1), 'i')))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), ('do_loop_head', 'i', ('Num', (1, 1), '1'), ('Num', (1, 1), '5'), ('UnaryOp', (1, 1), ('USub',), ('Num', (1, 1), '1'))), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Name', (1, 1), 'i'))])], []),
    ('Select', (1, 1), ('Name', (1, 1), 'k'), [('case_stmt', ('Num', (1, 1), '1'), [('SubroutineCall', (1, 1), 'a', [])]), ('case_stmt', ('Name', (1, 1), 'i'), [('SubroutineCall', (1, 1), 'b', [])])], None),
    ('Select', (1, 1), ('Name', (1, 1), 'k'), [('case_stmt', ('Num', (1, 1), '1'), [('SubroutineCall', (1, 1), 'a', [])]), ('case_stmt', ('Name', (1, 1), 'i'), [('SubroutineCall', (1, 1), 'b', [])])], ('case_default', [('SubroutineCall', (1, 1), 'c', [])])),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], []),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], []),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '7')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '3'))])]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '7')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))], [])]),
]

==> lfortran-0.2.0.tar.gz: lfortran-0.2.0/lfortran/ast/tests/controlflow_results.py <==
results = [
    ('WhileLoop', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'x'), ('Eq',), ('Name', (1, 1), 'y')), [('Assignment', (1, 1), ('Name', (1, 1), 'i'), ('BinOp', (1, 1), ('Name', (1, 1), 'i'), ('Add',), ('Num', (1, 1), '1'))), ('Cycle', (1, 1)), ('Exit', (1, 1))]),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('If', (1, 1), ('Name', (1, 1), 'b'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [])])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [('If', (1, 1), ('Name', (1, 1), 'b'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [('If', (1, 1), ('Name', (1, 1), 'c'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '2'))], [])])])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1')), ('Assignment', (1, 1), ('Name', (1, 1), 'y'), ('Num', (1, 1), '2'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('If', (1, 1), ('Name', (1, 1), 'a'), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))], [])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), None, None, None, None, [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Num', (1, 1), '1'))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), 'i', ('Num', (1, 1), '1'), ('Num', (1, 1), '5'), None, [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('BinOp', (1, 1), ('Name', (1, 1), 'x'), ('Add',), ('Name', (1, 1), 'i')))])], []),
    ('Subroutine', (1, 1), 'a', [], [], [], [('DoLoop', (1, 1), 'i', ('Num', (1, 1), '1'), ('Num', (1, 1), '5'), ('UnaryOp', (1, 1), ('USub',), ('Num', (1, 1), '1')), [('Assignment', (1, 1), ('Name', (1, 1), 'x'), ('Name', (1, 1), 'i'))])], []),
    ('Select', (1, 1), ('Name', (1, 1), 'k'), [('CaseStmt', ('Num', (1, 1), '1'), [('SubroutineCall', (1, 1), 'a', [])]), ('CaseStmt', ('Name', (1, 1), 'i'), [('SubroutineCall', (1, 1), 'b', [])])], []),
    ('Select', (1, 1), ('Name', (1, 1), 'k'), [('CaseStmt', ('Num', (1, 1), '1'), [('SubroutineCall', (1, 1), 'a', [])]), ('CaseStmt', ('Name', (1, 1), 'i'), [('SubroutineCall', (1, 1), 'b', [])])], [('SubroutineCall', (1, 1), 'c', [])]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], []),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], []),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '7')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))], [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '3'))])]),
    ('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '5')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '1'))], [('Where', (1, 1), ('Compare', (1, 1), ('Name', (1, 1), 'a'), ('Lt',), ('Num', (1, 1), '7')), [('Assignment', (1, 1), ('Name', (1, 1), 'B'), ('Num', (1, 1), '0'))], [])]),
]
